import sys
from src import config
from src.data import Message, compile_regex
from src.pyside6.trade_widget import TradeCollection
from PySide6 import QtCore
from PySide6.QtWidgets import QApplication, QMainWindow, QVBoxLayout, QTabWidget


class MainWindow(QMainWindow):
    def __init__(self):
        super().__init__()

        self.setWindowFlag(QtCore.Qt.FramelessWindowHint)
        self.setAttribute(QtCore.Qt.WA_TranslucentBackground)

        self.trades = {}

        self.setWindowTitle("My App")

        self.main_widget = QTabWidget(self)
        self.main_widget.setTabsClosable(True)
        self.main_widget.tabCloseRequested.connect(self.del_tab)
        self.setCentralWidget(self.main_widget)

    def new_trade(self, message: Message):
        if message.trade:
            unique_item = message.trade.unique_item()
            if unique_item in self.trades:
                self.trades[unique_item].add_trade(message)
            else:
                collection = TradeCollection(message, self)
                collection.setParent(self.main_widget)
                self.main_widget.addTab(collection, message.trade.item)
                self.trades[message.trade.unique_item()] = collection
                self.show()

    def del_collection(self, unique_item: str):
        del self.trades[unique_item]
        if not self.trades:
            self.hide()

    def del_tab(self, index: int):
        collection = self.main_widget.widget(index)
        assert isinstance(collection, TradeCollection)
        self.trades[collection.unique_item].deleteLater()
        del self.trades[collection.unique_item]
        if not self.trades:
            self.hide()


if __name__ == "__main__":
    conf = config.read_config(r'config.yaml')
    compile_regex(conf)
    text = '2021/03/08 23:24:52 17931875 bb3 [INFO Client 1492] @From Sinusal: Hi, I would like to buy your level 21 23% Vaal Impurity of Lightning ' \
        'listed for 18 chaos in Ritual (stash tab "$"; position: left 22, top 5)'
    text2 = '2021/03/08 23:24:52 17931875 bb3 [INFO Client 1492] @From NiceGuy: Hi, I would like to buy your level 21 23% Vaal Impurity of Lightning ' \
        'listed for 18 chaos in Ritual (stash tab "$"; position: left 22, top 5)'
    text3 = '2023/01/02 23:57:26 15123437 cffb0734 [INFO Client 16668] @From <SETSU?> LASTTRYPOEenjoyer: ' \
        'Hi, I would like to buy your Watcher\'s Eye, Prismatic Jewel listed for 2.5 divine in Sanctum (stash tab "$2"; position: left 8, top 7)'
    message = Message.from_text(text)
    message2 = Message.from_text(text2)
    message3 = Message.from_text(text3)
    app = QApplication(sys.argv)
    app.setStyle('Material')

    window = MainWindow()
    assert message
    assert message2
    assert message3
    window.new_trade(message)
    window.new_trade(message)
    window.new_trade(message2)
    window.new_trade(message3)

    app.exec()
